#
# spec file for package bemenu
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define bcond_with curses
Name:           bemenu
Version:        0.6.4
Release:        bp154.1.34
Summary:        Dynamic menu library and client program inspired by dmenu
License:        MIT
Group:          System/GUI/Other
URL:            https://github.com/Cloudef/bemenu
Source0:        https://github.com/Cloudef/bemenu/archive/%{version}.tar.gz
BuildRequires:  Mesa-devel
BuildRequires:  gcc-c++
BuildRequires:  make
BuildRequires:  pango-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-protocols)
BuildRequires:  pkgconfig(wayland-server)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xkbcommon) >= 0.3.2
%if %{with curses}
BuildRequires:  pkgconfig(ncurses)
%endif

%description
Dynamic menu library and client program inspired by dmenu with support
for X, Wayland and ncurses.

%package -n libbemenu0
Summary:        Dynamic menu library inspired by dmenu
# you need renderers
Group:          Development/Libraries/C and C++
Requires:       %{name}

%description -n libbemenu0
Library for Bemenu, dynamic menu inspired by dmenu.

%package devel
Summary:        Development files for bemenu
Group:          Development/Libraries/C and C++
Requires:       cmake
Requires:       gcc-c++
Requires:       libbemenu0 = %{version}
Requires:       pkgconfig

%description devel
Files required for development for Bemenu.

%prep
%setup -q

%if %{with curses}
# fix colliding name with our ncurses library specifics
sed -i 's@stdscr@std_scr@g' lib/renderers/curses/curses.c
%endif

%build
pkg-config --cflags wayland-client
%make_build PREFIX=%{_prefix} libdir=/lib64 clients x11 wayland curses

%install
%make_install PREFIX=%{_prefix} libdir=/%{_lib}

%post -n libbemenu0 -p /sbin/ldconfig
%postun -n libbemenu0 -p /sbin/ldconfig

%files -n libbemenu0
%{_libdir}/libbemenu.so.*

%files devel
%{_libdir}/libbemenu.so
%{_libdir}/pkgconfig/bemenu.pc
%{_includedir}/bemenu.h

%files
%{_bindir}/%{name}*
%dir %{_libdir}/bemenu/
%{_libdir}/bemenu/bemenu-renderer-*.so
%{_mandir}/man1/bemenu.1%{?ext_man}

%changelog
* Mon Dec  6 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.6.4:
  * fix scaling caused issue on window redimension on wayland #197
  * add -c center mode on wayland #198
  * Add option to configure cursor height #201
  * Add -s to disable title spacing on entries #203
  * Fix incorrect line height #207
  * lib/renderers/curses/curses.c: always use "%%s"-style
    format for printf()-style functions #211
  * Add horizontal alignment and improve center alignment #209
  * Add paste functionality #210
  * Instruction for installing dependencies #214
* Thu Jul 22 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.6.3:
  * Fixes key repeat rate in wayland
  * Ctrl-c now exits bemenu in x11 and wayland
  * Hidden files (dot files) are now ignored in bemenu-run
* Wed Jun  9 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.6.2:
  * Handle multiple seats (more) correctly
* Tue May 25 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.6.1:
  * Makes it possible to show bemenu on focused monitor on
    wayland #174
* Thu May 20 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.6.0:
  * Add custom key support
  * Add key_pending field to sync wayland keyboard event loops
  * Add --filter option.
  * Support hiding filter input (#150)
  * Use -m option for setting monitor name and monitor
  * Various fixes
* Sun Jul  5 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.5.0:
  * This release fixes rendering issues under HiDPI configuraitons
  Notable new features:
  * --scrollbar none
  * BEMENU_SCALE env variable which can be used to force scaling
    factor
* Tue Apr 14 2020 Michael Vetter <mvetter@suse.com>
- Use %%{_lib} macro
* Mon Apr 13 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.4.1:
  * This bug fix release fixes a build problem with missing
    wayland headers on some systems. #106
- Remove bemenu-pkgconfig.patch: contained in upstream
* Sun Apr 12 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.4.0:
  This release includes various bug fixes and some minor new features.
  Following behavior has changed by default:
  * The vertical UI now resembles vanilla dmenu more with the left
    padding added.
  * Scrollbar thickness has changed to 1 character thick instead 1
    pixel, to make it more visible on hidpi displays.
  * X11 should now contain windows class and name
  * Wayland shows bemenu only on single monitor now, to have the
    old behavior back you can use the -m all option. Note that there
    seems to be input bugs in Wayland backend currently, and I would
    appreciate if some Wayland developer could help figure those
    out! #98 #102
  * bemenu-run under curses won't fork anymore by default, to make
    bemenu-run under curses fork, use the --fork option, this option
    is no-op for any other backend.
  Notable new features:
  * BEMENU_OPTS env variable can be now used as a alternative way of specifying command line options for bemenu.
- Remove because upstreamed:
  * bemenu-0.3.0-boo1165235-ncurses.patch
  * bemenu-0.3.0-curses.patch
- Remove bemenu-0.3.0-wayland.patch: switch to makefile
- Add bemenu-pkgconfig.patch: https://github.com/Cloudef/bemenu/issues/106
* Fri Feb 28 2020 Michael Vetter <mvetter@suse.com>
- Add bemenu-0.3.0-wayland.patch: enable wayland renderer
* Fri Feb 28 2020 Michael Vetter <mvetter@suse.com>
- boo#1165235: Undefined symbol get_wch
  * Add bemenu-0.3.0-boo1165235-ncurses.patch:
    Search for ncursesw instead of ncurses
* Fri Dec 27 2019 Michael Vetter <mvetter@suse.com>
- Update to 0.3.0:
  * Uses default the monospace 10 font now to match dmenu
    and to be more robust
  * Hidpi support for wayland
- Add bemenu-0.3.0-curses.patch:
  See https://github.com/Cloudef/bemenu/pull/77
* Wed Oct 30 2019 Michael Vetter <mvetter@suse.com>
- Update to 0.2.0:
  * wayland: implement a proper repaint cycle
  * Add options for renderers
  * Add option to respect panel position
  * x11: add pango as dependency of the x11 rendere
  * bemenu: add --line-height / -H option
  * Add C-g shortcut to x11 and wayland
  * Add manpage
* Mon Mar  4 2019 mvetter@suse.com
- Update to first official release 0.1.0
- Remove service file
* Tue Feb  7 2017 callumjfarmer13@gmail.com
- update to 0.0.20161206
- dropped ncurses-fix.patch
* Mon May  9 2016 sleep_walker@opensuse.org
- bump to new git snapshot 0.0.20160412
- cleanup
* Thu Oct  8 2015 sleep_walker@opensuse.org
- fix whitespace inconsistency
- cleanup changelog to match reviewer's taste
- define patch unconditionaly (remove %%ifs around it)
- fix RPM group
- reformat description
- require only libxkbcommon 0.3.2 or higher
- remove 4th argument of defattr to match reviewer's taste
* Wed Oct  7 2015 sleep_walker@opensuse.org
- disable ncurses build for now as I can't locate library with
  wget_wch
* Sat Sep 26 2015 sleep_walker@opensuse.org
- updated snapshot (20150923)
- remove patches accepted by upstream
- enable curses backed again and fix it (ncurses-fix.patch and sed)
- clean up spec
* Mon Sep 21 2015 sleep_walker@opensuse.org
- let there be bemenu!
